# Modeling: Project Fact Sheet (Meta Model v3)
### On this page
  * [What are Projects in LeanIX?](https://help.sap.com/docs/leanix/ea/project-modeling-v3#what-are-projects-in-leanix?)
  * [Creating New Projects](https://help.sap.com/docs/leanix/ea/project-modeling-v3#creating-new-projects)
  * [Viewing Existing Projects](https://help.sap.com/docs/leanix/ea/project-modeling-v3#viewing-existing-projects)
  * [Project Reports](https://help.sap.com/docs/leanix/ea/project-modeling-v3#project-reports)


Measure the impact of projects on applications and domains, and see their suitability with your business strategy, using the Project Fact Sheets and Reports in LeanIX.
**Note**
This page is a modeling guideline for Meta Model v3. For updated guidelines for Meta Model v4 see [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
As an enterprise architect, you may want to measure the impact of projects on applications and domains, in order to measure suitability with the corporate vision. This article shows you how to do that using the Project Fact Sheet.
